# pulp_deb-client
Fetch, Upload, Organize, and Distribute Software Packages

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 2.14.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pulpcore.client.pulp_deb
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pulpcore.client.pulp_deb
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import pulpcore.client.pulp_deb
from pulpcore.client.pulp_deb.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://pulp
# See configuration.py for a list of all supported configuration parameters.
configuration = pulpcore.client.pulp_deb.Configuration(
    host = "http://pulp"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = pulpcore.client.pulp_deb.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure API key authorization: cookieAuth
configuration = pulpcore.client.pulp_deb.Configuration(
    host = "http://pulp",
    api_key = {
        'Session': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Session'] = 'Bearer'


# Enter a context with an instance of the API client
with pulpcore.client.pulp_deb.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pulpcore.client.pulp_deb.ContentGenericContentsApi(api_client)
    relative_path = 'relative_path_example' # str | Path where the artifact is located relative to distributions base_path
artifact = 'artifact_example' # str | Artifact file representing the physical content (optional)
file = '/path/to/file' # file | An uploaded file that may be turned into the artifact of the content unit. (optional)
repository = 'repository_example' # str | A URI of a repository the new content unit should be associated with. (optional)

    try:
        # Create a generic content
        api_response = api_instance.create(relative_path, artifact=artifact, file=file, repository=repository)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ContentGenericContentsApi->create: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ContentGenericContentsApi* | [**create**](docs/ContentGenericContentsApi.md#create) | **POST** /pulp/api/v3/content/deb/generic_contents/ | Create a generic content
*ContentGenericContentsApi* | [**list**](docs/ContentGenericContentsApi.md#list) | **GET** /pulp/api/v3/content/deb/generic_contents/ | List generic contents
*ContentGenericContentsApi* | [**read**](docs/ContentGenericContentsApi.md#read) | **GET** {deb_generic_content_href} | Inspect a generic content
*ContentInstallerFileIndicesApi* | [**create**](docs/ContentInstallerFileIndicesApi.md#create) | **POST** /pulp/api/v3/content/deb/installer_file_indices/ | Create an installer file index
*ContentInstallerFileIndicesApi* | [**list**](docs/ContentInstallerFileIndicesApi.md#list) | **GET** /pulp/api/v3/content/deb/installer_file_indices/ | List InstallerFileIndices
*ContentInstallerFileIndicesApi* | [**read**](docs/ContentInstallerFileIndicesApi.md#read) | **GET** {deb_installer_file_index_href} | Inspect an installer file index
*ContentInstallerPackagesApi* | [**create**](docs/ContentInstallerPackagesApi.md#create) | **POST** /pulp/api/v3/content/deb/installer_packages/ | Create an installer package
*ContentInstallerPackagesApi* | [**list**](docs/ContentInstallerPackagesApi.md#list) | **GET** /pulp/api/v3/content/deb/installer_packages/ | List installer packages
*ContentInstallerPackagesApi* | [**read**](docs/ContentInstallerPackagesApi.md#read) | **GET** {deb_installer_package_href} | Inspect an installer package
*ContentPackageIndicesApi* | [**create**](docs/ContentPackageIndicesApi.md#create) | **POST** /pulp/api/v3/content/deb/package_indices/ | Create a package index
*ContentPackageIndicesApi* | [**list**](docs/ContentPackageIndicesApi.md#list) | **GET** /pulp/api/v3/content/deb/package_indices/ | List PackageIndices
*ContentPackageIndicesApi* | [**read**](docs/ContentPackageIndicesApi.md#read) | **GET** {deb_package_index_href} | Inspect a package index
*ContentPackageReleaseComponentsApi* | [**create**](docs/ContentPackageReleaseComponentsApi.md#create) | **POST** /pulp/api/v3/content/deb/package_release_components/ | Create a package release component
*ContentPackageReleaseComponentsApi* | [**list**](docs/ContentPackageReleaseComponentsApi.md#list) | **GET** /pulp/api/v3/content/deb/package_release_components/ | List package release components
*ContentPackageReleaseComponentsApi* | [**read**](docs/ContentPackageReleaseComponentsApi.md#read) | **GET** {deb_package_release_component_href} | Inspect a package release component
*ContentPackagesApi* | [**create**](docs/ContentPackagesApi.md#create) | **POST** /pulp/api/v3/content/deb/packages/ | Create a package
*ContentPackagesApi* | [**list**](docs/ContentPackagesApi.md#list) | **GET** /pulp/api/v3/content/deb/packages/ | List packages
*ContentPackagesApi* | [**read**](docs/ContentPackagesApi.md#read) | **GET** {deb_package_href} | Inspect a package
*ContentReleaseArchitecturesApi* | [**create**](docs/ContentReleaseArchitecturesApi.md#create) | **POST** /pulp/api/v3/content/deb/release_architectures/ | Create a release architecture
*ContentReleaseArchitecturesApi* | [**list**](docs/ContentReleaseArchitecturesApi.md#list) | **GET** /pulp/api/v3/content/deb/release_architectures/ | List release architectures
*ContentReleaseArchitecturesApi* | [**read**](docs/ContentReleaseArchitecturesApi.md#read) | **GET** {deb_release_architecture_href} | Inspect a release architecture
*ContentReleaseComponentsApi* | [**create**](docs/ContentReleaseComponentsApi.md#create) | **POST** /pulp/api/v3/content/deb/release_components/ | Create a release component
*ContentReleaseComponentsApi* | [**list**](docs/ContentReleaseComponentsApi.md#list) | **GET** /pulp/api/v3/content/deb/release_components/ | List release components
*ContentReleaseComponentsApi* | [**read**](docs/ContentReleaseComponentsApi.md#read) | **GET** {deb_release_component_href} | Inspect a release component
*ContentReleaseFilesApi* | [**create**](docs/ContentReleaseFilesApi.md#create) | **POST** /pulp/api/v3/content/deb/release_files/ | Create a release file
*ContentReleaseFilesApi* | [**list**](docs/ContentReleaseFilesApi.md#list) | **GET** /pulp/api/v3/content/deb/release_files/ | List release files
*ContentReleaseFilesApi* | [**read**](docs/ContentReleaseFilesApi.md#read) | **GET** {deb_release_file_href} | Inspect a release file
*ContentReleasesApi* | [**create**](docs/ContentReleasesApi.md#create) | **POST** /pulp/api/v3/content/deb/releases/ | Create a release
*ContentReleasesApi* | [**list**](docs/ContentReleasesApi.md#list) | **GET** /pulp/api/v3/content/deb/releases/ | List releases
*ContentReleasesApi* | [**read**](docs/ContentReleasesApi.md#read) | **GET** {deb_release_href} | Inspect a release
*DistributionsAptApi* | [**create**](docs/DistributionsAptApi.md#create) | **POST** /pulp/api/v3/distributions/deb/apt/ | Create an apt distribution
*DistributionsAptApi* | [**delete**](docs/DistributionsAptApi.md#delete) | **DELETE** {deb_apt_distribution_href} | Delete an apt distribution
*DistributionsAptApi* | [**list**](docs/DistributionsAptApi.md#list) | **GET** /pulp/api/v3/distributions/deb/apt/ | List apt distributions
*DistributionsAptApi* | [**partial_update**](docs/DistributionsAptApi.md#partial_update) | **PATCH** {deb_apt_distribution_href} | Update an apt distribution
*DistributionsAptApi* | [**read**](docs/DistributionsAptApi.md#read) | **GET** {deb_apt_distribution_href} | Inspect an apt distribution
*DistributionsAptApi* | [**update**](docs/DistributionsAptApi.md#update) | **PUT** {deb_apt_distribution_href} | Update an apt distribution
*PublicationsAptApi* | [**create**](docs/PublicationsAptApi.md#create) | **POST** /pulp/api/v3/publications/deb/apt/ | Create an apt publication
*PublicationsAptApi* | [**delete**](docs/PublicationsAptApi.md#delete) | **DELETE** {deb_apt_publication_href} | Delete an apt publication
*PublicationsAptApi* | [**list**](docs/PublicationsAptApi.md#list) | **GET** /pulp/api/v3/publications/deb/apt/ | List apt publications
*PublicationsAptApi* | [**read**](docs/PublicationsAptApi.md#read) | **GET** {deb_apt_publication_href} | Inspect an apt publication
*PublicationsVerbatimApi* | [**create**](docs/PublicationsVerbatimApi.md#create) | **POST** /pulp/api/v3/publications/deb/verbatim/ | Create a verbatim publication
*PublicationsVerbatimApi* | [**delete**](docs/PublicationsVerbatimApi.md#delete) | **DELETE** {deb_verbatim_publication_href} | Delete a verbatim publication
*PublicationsVerbatimApi* | [**list**](docs/PublicationsVerbatimApi.md#list) | **GET** /pulp/api/v3/publications/deb/verbatim/ | List verbatim publications
*PublicationsVerbatimApi* | [**read**](docs/PublicationsVerbatimApi.md#read) | **GET** {deb_verbatim_publication_href} | Inspect a verbatim publication
*RemotesAptApi* | [**create**](docs/RemotesAptApi.md#create) | **POST** /pulp/api/v3/remotes/deb/apt/ | Create an apt remote
*RemotesAptApi* | [**delete**](docs/RemotesAptApi.md#delete) | **DELETE** {deb_apt_remote_href} | Delete an apt remote
*RemotesAptApi* | [**list**](docs/RemotesAptApi.md#list) | **GET** /pulp/api/v3/remotes/deb/apt/ | List apt remotes
*RemotesAptApi* | [**partial_update**](docs/RemotesAptApi.md#partial_update) | **PATCH** {deb_apt_remote_href} | Update an apt remote
*RemotesAptApi* | [**read**](docs/RemotesAptApi.md#read) | **GET** {deb_apt_remote_href} | Inspect an apt remote
*RemotesAptApi* | [**update**](docs/RemotesAptApi.md#update) | **PUT** {deb_apt_remote_href} | Update an apt remote
*RepositoriesAptApi* | [**create**](docs/RepositoriesAptApi.md#create) | **POST** /pulp/api/v3/repositories/deb/apt/ | Create an apt repository
*RepositoriesAptApi* | [**delete**](docs/RepositoriesAptApi.md#delete) | **DELETE** {deb_apt_repository_href} | Delete an apt repository
*RepositoriesAptApi* | [**list**](docs/RepositoriesAptApi.md#list) | **GET** /pulp/api/v3/repositories/deb/apt/ | List apt repositorys
*RepositoriesAptApi* | [**modify**](docs/RepositoriesAptApi.md#modify) | **POST** {deb_apt_repository_href}modify/ | Modify Repository Content
*RepositoriesAptApi* | [**partial_update**](docs/RepositoriesAptApi.md#partial_update) | **PATCH** {deb_apt_repository_href} | Update an apt repository
*RepositoriesAptApi* | [**read**](docs/RepositoriesAptApi.md#read) | **GET** {deb_apt_repository_href} | Inspect an apt repository
*RepositoriesAptApi* | [**sync**](docs/RepositoriesAptApi.md#sync) | **POST** {deb_apt_repository_href}sync/ | Sync from remote
*RepositoriesAptApi* | [**update**](docs/RepositoriesAptApi.md#update) | **PUT** {deb_apt_repository_href} | Update an apt repository
*RepositoriesAptVersionsApi* | [**delete**](docs/RepositoriesAptVersionsApi.md#delete) | **DELETE** {deb_apt_repository_version_href} | Delete a repository version
*RepositoriesAptVersionsApi* | [**list**](docs/RepositoriesAptVersionsApi.md#list) | **GET** {deb_apt_repository_href}versions/ | List repository versions
*RepositoriesAptVersionsApi* | [**read**](docs/RepositoriesAptVersionsApi.md#read) | **GET** {deb_apt_repository_version_href} | Inspect a repository version
*RepositoriesAptVersionsApi* | [**repair**](docs/RepositoriesAptVersionsApi.md#repair) | **POST** {deb_apt_repository_version_href}repair/ | 


## Documentation For Models

 - [AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [ContentSummary](docs/ContentSummary.md)
 - [ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [DebAptDistribution](docs/DebAptDistribution.md)
 - [DebAptDistributionResponse](docs/DebAptDistributionResponse.md)
 - [DebAptPublication](docs/DebAptPublication.md)
 - [DebAptPublicationResponse](docs/DebAptPublicationResponse.md)
 - [DebAptRemote](docs/DebAptRemote.md)
 - [DebAptRemoteResponse](docs/DebAptRemoteResponse.md)
 - [DebAptRepository](docs/DebAptRepository.md)
 - [DebAptRepositoryResponse](docs/DebAptRepositoryResponse.md)
 - [DebBasePackage](docs/DebBasePackage.md)
 - [DebBasePackageResponse](docs/DebBasePackageResponse.md)
 - [DebGenericContent](docs/DebGenericContent.md)
 - [DebGenericContentResponse](docs/DebGenericContentResponse.md)
 - [DebInstallerFileIndex](docs/DebInstallerFileIndex.md)
 - [DebInstallerFileIndexResponse](docs/DebInstallerFileIndexResponse.md)
 - [DebPackageIndex](docs/DebPackageIndex.md)
 - [DebPackageIndexResponse](docs/DebPackageIndexResponse.md)
 - [DebPackageReleaseComponent](docs/DebPackageReleaseComponent.md)
 - [DebPackageReleaseComponentResponse](docs/DebPackageReleaseComponentResponse.md)
 - [DebRelease](docs/DebRelease.md)
 - [DebReleaseArchitecture](docs/DebReleaseArchitecture.md)
 - [DebReleaseArchitectureResponse](docs/DebReleaseArchitectureResponse.md)
 - [DebReleaseComponent](docs/DebReleaseComponent.md)
 - [DebReleaseComponentResponse](docs/DebReleaseComponentResponse.md)
 - [DebReleaseFile](docs/DebReleaseFile.md)
 - [DebReleaseFileResponse](docs/DebReleaseFileResponse.md)
 - [DebReleaseResponse](docs/DebReleaseResponse.md)
 - [DebVerbatimPublication](docs/DebVerbatimPublication.md)
 - [DebVerbatimPublicationResponse](docs/DebVerbatimPublicationResponse.md)
 - [PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PaginateddebAptDistributionResponseList](docs/PaginateddebAptDistributionResponseList.md)
 - [PaginateddebAptPublicationResponseList](docs/PaginateddebAptPublicationResponseList.md)
 - [PaginateddebAptRemoteResponseList](docs/PaginateddebAptRemoteResponseList.md)
 - [PaginateddebAptRepositoryResponseList](docs/PaginateddebAptRepositoryResponseList.md)
 - [PaginateddebBasePackageResponseList](docs/PaginateddebBasePackageResponseList.md)
 - [PaginateddebGenericContentResponseList](docs/PaginateddebGenericContentResponseList.md)
 - [PaginateddebInstallerFileIndexResponseList](docs/PaginateddebInstallerFileIndexResponseList.md)
 - [PaginateddebPackageIndexResponseList](docs/PaginateddebPackageIndexResponseList.md)
 - [PaginateddebPackageReleaseComponentResponseList](docs/PaginateddebPackageReleaseComponentResponseList.md)
 - [PaginateddebReleaseArchitectureResponseList](docs/PaginateddebReleaseArchitectureResponseList.md)
 - [PaginateddebReleaseComponentResponseList](docs/PaginateddebReleaseComponentResponseList.md)
 - [PaginateddebReleaseFileResponseList](docs/PaginateddebReleaseFileResponseList.md)
 - [PaginateddebReleaseResponseList](docs/PaginateddebReleaseResponseList.md)
 - [PaginateddebVerbatimPublicationResponseList](docs/PaginateddebVerbatimPublicationResponseList.md)
 - [PatcheddebAptDistribution](docs/PatcheddebAptDistribution.md)
 - [PatcheddebAptRemote](docs/PatcheddebAptRemote.md)
 - [PatcheddebAptRepository](docs/PatcheddebAptRepository.md)
 - [PolicyEnum](docs/PolicyEnum.md)
 - [RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [RepositorySyncURL](docs/RepositorySyncURL.md)
 - [RepositoryVersion](docs/RepositoryVersion.md)
 - [RepositoryVersionResponse](docs/RepositoryVersionResponse.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## cookieAuth

- **Type**: API key
- **API key parameter name**: Session
- **Location**: 


## Author

pulp-list@redhat.com


